
/*****************************************************************************
 *   Revision History
 *   ------------------
 *   Name         :  UserServiceImpl.java
 *   Author       :  Neha_mittal03
 *   Date         :  20/August/2007
 *   Description  :  This class implements the services declared  in  interface UserService.java
 *
 *   $Log		  : UserServiceImpl.java$
 *   Modification Log:
 *	 * Date                 Author                     Description
 *	 * ------------------------------------------------------------
 *	 * 20-Aug-2007          Neha_mittal03              Created
 *	 * 16-Jun-2008 			Abraham_Mammen			   Created function addSessionDetails for performance tuning 
 *   * 23-Jul-2008			Suja_Pillai				   Added a new parameter for multiple association of roles during User creation in createUser function
 *   * 13-Jul-2009			Marian_Josephus	 		   Added rollback and transaction begin code to all functions with commit.
 *	 #  
 *	 #  
 *****************************************************************************/
package com.infosys.itaw.user.business.service.impl;

/* Importing java classes */
import java.security.spec.KeySpec;
import java.util.List;

import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.SecretKeyFactory;
import javax.crypto.spec.DESKeySpec;

import org.hibernate.HibernateException;
import org.hibernate.Transaction;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.infosys.itaw.user.business.service.UserService;

/* Importing ITAW files */

import com.infosys.itaw.user.persistence.dao.UserDAO;
//import com.infosys.itaw.role.persistence.dto.RoleDTO;
//import com.infosys.itaw.scriptexecution.business.service.ScriptExecutionService;
import com.infosys.itaw.user.persistence.dto.SessionDetailsDTO;
import com.infosys.itaw.user.persistence.dto.UserDTO;

import itawexception.ItawException;
import sun.misc.BASE64Decoder;
import sun.misc.BASE64Encoder;
//import util.UtilFunctions; /*

/**
 * This is the service implementation class for Manage User Module.
 * 
 * @author Neha_mittal03
 */
@Service("UserService")
@Transactional
public class UserServiceImpl implements UserService {

	@Autowired
	UserDAO userdao;
	// DAOService hibernateDAOService;
	// LoggingService log;
	// Session session=null;

	UserDTO userVO = new UserDTO();
	private KeySpec keySpec;
	private SecretKeyFactory keyFactory;
	private Cipher cipher;

	public UserServiceImpl() throws ItawException {
		try {
			// hibernateDAOService = (DAOService)
			// RadienServiceLocator.getInstance().getService("default-HibernateDAOService");
			// userdao = (UserDAO) hibernateDAOService.getDAO("UserDAO");

			// session=HibernateSessionUtil.currentSession("testfactory");

		}
		/*
		 * catch (DAOServiceException e) { throw new ItawException("ITAW11175");
		 * }
		 */
		/*
		 * catch (DBException e) { throw new ItawException("ITAW11176"); }
		 */
		catch (Exception e) {
			// System.out.println("Service Initialization error");
			throw new ItawException("ITAW11177");
		}
	}

	/**
	 * @param strPassword
	 * @return
	 */
	public String encrypt(String strPassword) throws ItawException {
		String encryptionKey = "123456789012345678901234567890";
		String encryptionScheme = "DES";

		try {

			byte[] keyAsBytes = encryptionKey.getBytes("UTF8");
			keySpec = new DESKeySpec(keyAsBytes);

			keyFactory = SecretKeyFactory.getInstance(encryptionScheme);
			cipher = Cipher.getInstance(encryptionScheme);

			SecretKey key = keyFactory.generateSecret(keySpec);
			cipher.init(Cipher.ENCRYPT_MODE, key);
			byte[] cleartext = strPassword.getBytes("UTF8");
			byte[] ciphertext = cipher.doFinal(cleartext);

			BASE64Encoder base64encoder = new BASE64Encoder();
			return base64encoder.encode(ciphertext);

		} catch (Exception e) {
			throw new ItawException("ITAW0582");
		}

	}

	public String decrypt(String strEncryptedPassword) throws ItawException {
		String encryptionKey = "123456789012345678901234567890";
		String encryptionScheme = "DES";

		try {

			byte[] keyAsBytes = encryptionKey.getBytes("UTF8");
			keySpec = new DESKeySpec(keyAsBytes);

			keyFactory = SecretKeyFactory.getInstance(encryptionScheme);
			cipher = Cipher.getInstance(encryptionScheme);

			SecretKey key = keyFactory.generateSecret(keySpec);

			cipher.init(Cipher.DECRYPT_MODE, key);

			BASE64Decoder base64decoder = new BASE64Decoder();

			byte[] cleartext = base64decoder.decodeBuffer(strEncryptedPassword);
			byte[] ciphertext = cipher.doFinal(cleartext);

			return new String(ciphertext);

		} catch (Exception e) {
			throw new ItawException("ITAW18475");
		}
	}

	/**
	 * checks whether user exists
	 * 
	 * @param strUserName
	 * @return bCheckUser - True if exists
	 */
	public boolean checkUserExists(String strUserName) throws ItawException {
		boolean bCheckUser = false;
		// System.out.println("inside service");
		try {
			// creating an instance of user DAO
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");

			// calling the DAO method to check whether the given name exists

			bCheckUser = userdao.checkUserExists(strUserName);

		}

		// catch(DAOServiceException daoException){
		//
		// throw new ItawException("ITAW0534");
		// }
		catch (ItawException itawException) {

			throw itawException;
		} catch (Exception exception) {
			throw new ItawException("ITAW0535");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11397");
			}
		}

		return bCheckUser;
	}

	/**
	 * retrieves all users
	 * 
	 * @param NIL
	 * @return lstUser - list of Users
	 */
	public List listUsers() throws ItawException {

		System.out.println("  ITAW-UserserviceImpl" + "inside service implementation");
		// lstUser stores the list of users
		List lstUser = null;
		try {

			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");
			// session=HibernateSessionUtil.currentSession("testfactory");
			System.out.println("  ITAW-UserserviceImpl" + "inside service implementation DAO is created");
			// invoking the DAO method and stores the return value
			lstUser = userdao.listUsers();
			UserDTO usr = (UserDTO) lstUser.get(0);
			System.out.println(
					"  ITAW-UserserviceImpl" + "retrieved the User:" + usr.getiUserId() + " " + usr.getStrUserName());
			// session.clear();
		}
		// catch(DAOServiceException daoException)
		// {
		// //session.clear();
		// throw new ItawException("ITAW0536");
		// }
		catch (ItawException itawException) {
			// session.clear();
			throw itawException;
		} catch (Exception exception) {
			// session.clear();
			throw new ItawException("ITAW0537");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11398");
			}
		}
		return lstUser;
	}

	public List listUser(int iUserId) throws ItawException {

		// lstProject stores the list of projects
		List lstUser = null;
		try {
			// session=HibernateSessionUtil.currentSession("testfactory");
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");

			// invoking the DAO method and stores the return value
			lstUser = userdao.getUserByUserID(iUserId);
			UserDTO user = (UserDTO) lstUser.get(0);
			System.out.println("itaw:log" + "retrieved the User:" + user.getiUserId() + " " + user.getStrUserName());
			// session.clear();
		}
		// catch(DAOServiceException daoException)
		// {
		// //session.clear();
		// throw new ItawException("ITAW0538");
		// }
		catch (ItawException ITAWException) {
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// session.clear();
			throw new ItawException("ITAW0539");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11399");
			}
		}
		// returning the result
		return lstUser;
	}

	/**
	 * creates a user
	 * 
	 * @param user,arrRoleId
	 * @return iResult - 1 for success and 0 for failure *
	 * @Modification Log: Date Author Description
	 *               ------------------------------------------------------------
	 *               23-Jul-2008 Suja_Pillai Added a new parameter for multiple
	 *               association of roles
	 */
	public int createUser(UserDTO user, int arrRoleId[]) throws ItawException {
		System.out.println("logger1" + "inside the create user methods");
		// This variable holds the return value of method
		int iResult = 1;
		Transaction transaction = null;
		String strPassword = user.getStrPassword();
		String strEncryptPassword = encrypt(strPassword);
		System.out.println("logger1" + strEncryptPassword);
		user.setStrPassword(strEncryptPassword);

		try {
			transaction = userdao.getSession().beginTransaction();
			// Begining transaction

			// invoking the DAO method and stores the return value
			iResult = userdao.createUser(user);

			System.out.println(" ITAW-UserserviceImpl" + "inserted successfully");
			// System.out.println();
			// Added a loop for mutiple association of role ids while user
			// creation
			for (int i = 0; i < arrRoleId.length; i++) {
				userdao.associateNewUserRole(arrRoleId[i], iResult);
				System.out.println(" ITAW-UserserviceImpl" + "inserted associations successfully");
			}
			System.out.println("session = "+userdao.getSession().isOpen());
			System.out.println("transaction = " + transaction.isActive() +" = "+ transaction);
			transaction.commit();

		} catch (ItawException ITAWException) {
			// Rollback code
			try {
				transaction.rollback();
			}
			// ToImplement
			// catch (HibernateHibernateException e) {
			// throw new ItawException("ITAW12501");
			// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12502");
			}
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// Rollback code
			try {
				userdao.getTransaction().rollback();
			}
			// ToImplement
			// catch (HibernateHibernateException e) {
			// throw new ItawException("ITAW12503");
			// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12504");
			}
			// session.clear();
			throw new ItawException("ITAW0541");

		} finally {
			try {
				userdao.getSession().flush();
				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11400");
			}
		}
		return iResult;
	}

	/***************************************************************************
	 * Add userid to session details.
	 * 
	 * @param sessiondetails
	 * @return iResult 1 for success and 0 for failure
	 * @Modification Log: Date Author Description
	 *               ------------------------------------------------------------
	 *               16-Jun-2008 Abraham_Mammen Created function for performance
	 *               tuning
	 **************************************************************************/
	public int addSessionDetails(SessionDetailsDTO sessiondetails) throws ItawException {
		System.out.println("logger1" + "inside the create user methods");
		// This variable holds the return value of method
		int iResult = 1;

		try {
			// Begining transaction
			userdao.getSession().beginTransaction();
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");

			// session=HibernateSessionUtil.currentSession("testfactory");
			// invoking the DAO method and stores the return value
			iResult = userdao.addSessionDetails(sessiondetails);

			// committing the transaction
			userdao.getTransaction().commit();
			System.out.println(" ITAW-UserserviceImpl" + "inserted successfully");

			// session.clear();
		}
		// catch(DAOServiceException daoException)
		// {
		// //session.clear();
		// throw new ItawException("ITAW0540");
		// }
		catch (ItawException ITAWException) {
			// Rollback code
			try {
				userdao.getTransaction().rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12502");
			}
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// Rollback code
			try {
				userdao.getTransaction().rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12504");
			}
			// session.clear();
			throw new ItawException("ITAW12611");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException(" ITAW11401");
			}
		}

		return iResult;
	}

	public String fetchDecryptedPassword(int iUserId) throws ItawException {
		String strDecryptedPassword = null;
		try {
			String tempPass = userdao.fetchUserPassword(iUserId);

			if (tempPass != null && !tempPass.isEmpty()) {
				strDecryptedPassword = this.decrypt(tempPass);
			}

		} catch (ItawException ITAWException) {
			throw ITAWException;
		} catch (Exception exception) {
			throw new ItawException("ITAW0539");
		}
		// returning the result
		return strDecryptedPassword;
	}

	public int fetchUserId(String strUserName) throws ItawException {
		int iResult = -1;
		try {
			// invoking the DAO method and stores the return value
			iResult = userdao.fetchUserID(strUserName);
		} catch (ItawException ITAWException) {
			throw ITAWException;
		} catch (Exception exception) {
			throw new ItawException("ITAW0539");
		}
		// returning the result
		return iResult;
	}

	/**
	 * delete the user corresponding to a particular userId
	 * 
	 * @param iUserId
	 *            - User ID
	 * @return iResult - 1 for success and 0 for failure
	 */
	public int deleteUsers(int iUserId) throws ItawException {
		// This variable holds the return value of method
		int iResult = 0;
		Transaction transaction = null;
		try {
			// Begining transaction
			transaction=userdao.getSession().beginTransaction();
			// session=HibernateSessionUtil.currentSession("testfactory");
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");

			// invoking the DAO method and stores the return value
			iResult = userdao.deleteUsers(iUserId);

			// committing the transaction
			transaction.commit();
			System.out.println(" ITAW-UserserviceImpl" + " user deleted successfully in impl");
			// session.clear();
		}
		// catch(DAOServiceException daoException){
		// //session.clear();
		// throw new ItawException("ITAW0542");
		// }
		catch (ItawException ITAWException) {
			// Rollback code
			try {
				transaction.rollback();
			}
			// ToImplement
			// catch (HibernateHibernateException e) {
			// throw new ItawException("ITAW12501");
			// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12502");
			}
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// Rollback code
			try {
				transaction.rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("sITAW12504");
			}
			// session.clear();
			throw new ItawException("ITAW0543");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11402");
			}
		}
		return iResult;
	}

	/**
	 * modifies the user
	 * 
	 * @param UserVO
	 *            - User
	 * @return iResult - 1 for success and 0 for failure
	 */
	public UserDTO modifyUser(UserDTO UserVO, int iUserId) throws ItawException {
		// This variable holds the return value of method
		int iResult = 0;
		Transaction transaction = null;
		UserVO.setiUserId(iUserId);
		// System.out.println("user ID after setting is "+UserVO.getiUserId());

		try {
			// Begining transaction
			userdao.getSession();
			// session=HibernateSessionUtil.currentSession("testfactory");
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");

			// System.out.println("user ID in service impl is
			// "+userVO.getiUserId());
			System.out.println(" ITAW-UserserviceImpl" + " user modified  successfully in impl" + userVO.getiUserId());
			// invoking the DAO method and stores the return value
			iResult = userdao.modifyUser(UserVO, iUserId);
			//userdao.create(UserVO);
			// System.out.println("The result is"+ iResult);
			// committing the transaction
			//transaction.commit();
			// session.clear();

		}
		// catch(DAOServiceException daoException){
		// //session.clear();
		// throw new ItawException("ITAW0544");
		// }
		catch (ItawException ITAWException) {
			// Rollback code
			try {
				transaction.rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12502");
			}
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// Rollback code
			try {
				transaction.rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12504");
			}
			// session.clear();
			throw new ItawException("ITAW0545");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11403");
			}
		}
		return UserVO;
	}

	/**
	 * retrieves the roles corresponding to a given userId
	 * 
	 * @param iUserId-the
	 *            UserId
	 * @return lstRoles : list of roles
	 */
	public List fetchRole(int iUserId) throws ItawException {
		// System.out.println("In fetch Roles Impl");
		// lstRoles stores the list of roles
		List lstRoles = null;
		try {
			// session=HibernateSessionUtil.currentSession("testfactory");
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");
			System.out.println(" ITAW-UserserviceImpl" + "Inside Impl.Going to DAO");
			// invoking the DAO method and stores the return value
			lstRoles = userdao.fetchRole(iUserId);
			System.out.println(" ITAW-UserserviceImpl" + "retrieved the Role Details");
			// session.clear();
		}
		// catch(DAOServiceException daoException){
		// //session.clear();
		// throw new ItawException("ITAW0546");
		// }
		catch (ItawException ITAWException) {
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// session.clear();
			throw new ItawException("ITAW0547");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11404");
			}
		}
		return lstRoles;
	}

	public List fetchProject(int iUserId) throws ItawException {
		// System.out.println("In fetch Project Impl");
		// lstRoles stores the list of roles
		List project = null;
		try {
			// session=HibernateSessionUtil.currentSession("testfactory");
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");
			System.out.println(" ITAW-UserserviceImpl" + "Inside Impl.Going to DAO");
			// invoking the DAO method and stores the return value
			project = userdao.fetchProjectMappedToUserByUserID(iUserId);
			System.out.println(" ITAW-UserserviceImpl" + "retrieved the Role Details");
			// session.clear();
		}
		// catch(DAOServiceException daoException){
		// //session.clear();
		// throw new ItawException("ITAW0548");
		// }
		catch (ItawException ITAWException) {
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// session.clear();
			throw new ItawException("ITAW0549");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11405");
			}
		}
		return project;
	}

	/**
	 * retrieves all roles
	 * 
	 * @param NIL
	 * @return lstRoles - list of roles
	 */
	public List fetchRoles() throws ItawException {

		// lstProject stores the list of roles
		List lstRoles = null;
		try {
			// session=HibernateSessionUtil.currentSession("testfactory");
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");

			// invoking the DAO method and stores the return value
			lstRoles = userdao.fetchRoles();

			// RoleDTO role=(RoleDTO)lstRoles.get(0);
			// System.out.println(" ITAW-UserserviceImpl","retrieved the
			// Roles:"+role.getIRoleId()+" "+role.getStrRoleName());
			// session.clear();
		}
		// catch(DAOServiceException daoException){
		// //session.clear();
		// throw new ItawException("ITAW0550");
		// }
		catch (ItawException ITAWException) {
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// session.clear();
			throw new ItawException("ITAW0551");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11406");
			}
		}
		return lstRoles;
	}

	/**
	 * @param iUserId
	 *            the user id
	 * @param iRoleId
	 *            the role id disassociate roles to user
	 * @return iResult 1 for success and 0 for failure
	 */

	public int disassociateUserRole(int roleId, int userId) throws ItawException {
		int iResult = 0;
		try {
			// Begining transaction
			userdao.getSession().beginTransaction();
			// session=HibernateSessionUtil.currentSession("testfactory");
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");
			// invoking the DAO method and stores the return value

			iResult = userdao.disassociateUserRole(roleId, userId);
			// committing the transaction
			userdao.getTransaction().commit();
			System.out.println("logger1" + "deleted successfully");
			// session.clear();

		}
		// catch(DAOServiceException daoException){
		// //session.clear();
		// throw new ItawException("ITAW0552");
		// }
		catch (ItawException ITAWException) {
			// Rollback code
			try {
				userdao.getTransaction().rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12502");
			}
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// Rollback code
			try {
				userdao.getTransaction().rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12504");
			}
			// session.clear();
			throw new ItawException("ITAW0553");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11407");
			}
		}
		return iResult;
	}

	/**
	 * @param iUserId
	 *            the user id
	 * @param iRoleId
	 *            the role id associate roles to user
	 * @return iResult 1 for success and 0 for failure
	 */

	public int associateNewUserRole(int iRoleId, int iUserId) throws ItawException {
		int iResult = 0;
		try { // Begining transaction
			userdao.getSession().beginTransaction();
			// session=HibernateSessionUtil.currentSession("testfactory");
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");
			// invoking the DAO method and stores the return value
			iResult = userdao.associateNewUserRole(iRoleId, iUserId);
			// committing the transaction
			userdao.getTransaction().commit();
			System.out.println("AssociateUserRole-Service" + "Inserted successfully");
			// session.clear();
		}
		// catch(DAOServiceException daoException){
		// //session.clear();
		// throw new ItawException("ITAW0554");
		// }
		catch (ItawException ITAWException) {
			// Rollback code
			try {
				userdao.getTransaction().rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12502");
			}
			// session.clear();
			throw ITAWException;
		} catch (Exception exception) {
			// Rollback code
			try {
				userdao.getTransaction().rollback();
			} // ToImplement
				// catch (HibernateHibernateException e) {
				// throw new ItawException("ITAW12501");
				// }
			catch (HibernateException e) {
				throw new ItawException("ITAW12504");
			}
			// session.clear();
			throw new ItawException("ITAW0555");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11408");
			}
		}
		return iResult;
	}

	public List searchRole(String strRoleName) throws ItawException {
		List lstSearchRole = null;
		try {
			// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");
			lstSearchRole = userdao.searchRole(strRoleName);
			System.out.println("Project Service logger" + "Retrieved Roles:" + lstSearchRole.size());

		}
		// catch(DAOServiceException daoException){
		//
		// throw new ItawException("ITAW0580");
		// }
		catch (ItawException ITAWException) {

			throw ITAWException;
		} catch (Exception exception) {
			throw new ItawException("ITAW0581");
		} finally {
			try {

				userdao.closeSession();

			} catch (HibernateException e) {
				throw new ItawException("ITAW11409");
			}
		}
		return lstSearchRole;
	}

	/**
	 * This method resets the password of a user
	 * 
	 * @param userDTO,iUserId
	 * @return iResult - 1 for success and 0 for failure
	 */

	public int resetPassword(String strPassWord, int iUserId) throws ItawException {
		{
			// This variable holds the return value of method
			int iResult = 0;
			String strEncryptPassword = "";
			strEncryptPassword = encrypt(strPassWord);
			System.out.println("logger1" + strEncryptPassword);
			
			try {
				// Begining transaction
				userdao.getSession().beginTransaction();
				// session=HibernateSessionUtil.currentSession("testfactory");
				// userdao = (UserDAO)hibernateDAOService.getDAO("UserDAO");

				// invoking the DAO method and stores the return value
				iResult = userdao.resetPassword(strEncryptPassword, iUserId);
				// System.out.println("The result is"+ iResult);
				// committing the transaction
				userdao.getTransaction().commit();
				// session.clear();

			}
			// catch(DAOServiceException daoException){
			// //session.clear();
			// throw new ItawException("ITAW0596");
			// }
			catch (ItawException ITAWException) {
				// Rollback code
				try {
					userdao.getTransaction().rollback();
				} // ToImplement
					// catch (HibernateHibernateException e) {
					// throw new ItawException("ITAW12501");
					// }
				catch (HibernateException e) {
					throw new ItawException("ITAW12502");
				}
				// session.clear();
				throw ITAWException;
			} catch (Exception exception) {
				// Rollback code
				try {
					userdao.getTransaction().rollback();
				} // ToImplement
					// catch (HibernateHibernateException e) {
					// throw new ItawException("ITAW12501");
					// }
				catch (HibernateException e) {
					throw new ItawException("ITAW12504");
				}
				// session.clear();
				throw new ItawException("ITAW0597");
			} finally {
				try {

					userdao.closeSession();

				} catch (HibernateException e) {
					throw new ItawException("ITAW11410");
				}
			}
			return iResult;
		}

	}

	public String getName() {
		// TODO Auto-generated method stub
		return null;
	}

}
