package com.infosys.itaw.util;


import java.io.InputStream;
import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathFactory;

import org.hibernate.Criteria;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.Transaction;
import org.springframework.beans.factory.annotation.Autowired;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import itawexception.ItawException;

public class GenericHibernateDAO  {

	private String className;
	private Map<String, String> queryMap = new HashMap<String, String>();
	protected String sessionFactoryName = "";
	protected Session session;
	private SessionFactory sessionFactory;

	@Autowired
	public void setSessionFactory(SessionFactory factory) {
		sessionFactory = factory;

	}

	public GenericHibernateDAO() {
		// Initiate hibernate session
		// getSession();
		this.className = getClass().getSimpleName();
		DocumentBuilderFactory docFactory;
		/** The doc builder. */
		DocumentBuilder docBuilder;
		Document xmlDoc;
		XPath xpath;
		XPathExpression exp;
		NodeList nodelist;
		try {

			InputStream queryFile = this.getClass().getClassLoader()
					.getResourceAsStream("etc/HibernateDIDAOConfig.xml");
			docFactory = DocumentBuilderFactory.newInstance();
			docBuilder = docFactory.newDocumentBuilder();
			xmlDoc = docBuilder.parse(queryFile);
			xmlDoc.getDocumentElement().normalize();
			xpath = XPathFactory.newInstance().newXPath();
			// Filtering queries for current DAO
			exp = xpath
					.compile("/DAOConfigRoot/DAOConfig/HibernateDAO[DAOName='"
							+ className + "']/Query");
			nodelist = (NodeList) exp.evaluate(xmlDoc, XPathConstants.NODESET);
			System.out.println("Initializing " + className);

			// Add queries into queryMap
			for (int i = 0; i < nodelist.getLength(); i++) {
				Element e = (Element) nodelist.item(i);
				String queryName = e.getAttribute("name").trim();
				String sql = e.getAttribute("sql").trim();
				if (this.queryMap.get(queryName) == null)
					this.queryMap.put(queryName, sql);
			}
		} catch (Exception e) {
			System.out.println("Error while intializing DAO object:"
					+ e.getMessage());
			e.printStackTrace();
		}

	}

	public Session getSession() {

		return sessionFactory.openSession();
	}

	protected String getSQL(String queryName) {
		return (String) this.queryMap.get(queryName);
	}

	protected Query createQuery(String queryString) {
		
		return getSession().createQuery(queryString);
	}

	public void closeSession() {

	}

	public Serializable create(Object object) throws ItawException {
		checkClass(object);
		Serializable result=null;
		try {
			Session session =getSession();
			Transaction transaction=session.beginTransaction();
			result=session.save(object);
			transaction.commit();
			
			
		} catch (Exception e) {
			throw new ItawException(
					"Exception at the time of persisting the object =  "
							+ object, e);
		}
		return result;
	}
	public void createChild(Object object) throws ItawException {
		checkClass(object);
		
		try {
			Session session =getSession();
			Transaction transaction=session.beginTransaction();
			session.persist(object);
			transaction.commit();
			
			
		} catch (Exception e) {
			throw new ItawException(
					"Exception at the time of persisting the object =  "
							+ object, e);
		}
		
	}

	public Object get(Class className, Serializable arg) throws ItawException {

		try {
			Object object = getSession().get(className, arg);
			return object;
		} catch (Exception e) {
			throw new ItawException(
					" Exception at the time of fetching the object", e);
		}
	}

	public Object saveOrUpdate(Object object) throws ItawException{
		checkClass(object);
		try {
			getSession().saveOrUpdate(object);

			return object;
		} catch (Exception e) {
			getSession().getTransaction().rollback();
			throw new ItawException("Exception at the time of persisting the object =  "+ object, e);
		}
	}

	public void delete(Object obj) throws ItawException {
		try {
			getSession().delete(obj);
		} catch (Exception e) {
			getSession().getTransaction().rollback();
			throw new ItawException(
					"Exception at the time of deleting the object = " + obj, e);
		}
	}

	public void update(Object object) throws ItawException {
		checkClass(object);
		try {
			Session session =getSession();
			session.beginTransaction();
			session.update(object);
			session.getTransaction().commit();
			session.close();
	
		} catch (Exception e) {
			getSession().getTransaction().rollback();
			throw new ItawException("Exception at the time of updating the object" + object,e);
		}
	}
	
	public Criteria createCriteria(Class arg){
		return getSession().createCriteria(arg);
	}
	private void checkClass(Object object) throws ItawException {
		if (object == null)
			throw new ItawException(
					"Error at the time of checking the Class: " + object);
	}

	public Transaction getTransaction() throws HibernateException {
		return getSession().getTransaction();
	}

}